@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2012-2016 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2012-2018 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <stdio.h>
 #include <math.h>
 #include "alsathread.h"
+#include "timers.h"
 
 
 Alsathread::Alsathread (Alsa_pcmi *alsadev, int mode) :
@@ -39,8 +40,6 @@ Alsathread::Alsathread (Alsa_pcmi *alsadev, int mode) :
     _w1 = 2 * M_PI * 0.1 * _dt;
     _w2 = _w1 * _w1;
     _w1 *= 1.6;
-    // Time wraps around after 2^28 usecs.
-    _jtmod = ldexp (1e-6, 28);
 }
 
 
@@ -161,7 +160,7 @@ void Alsathread::thr_main (void)
     {
         // Wait for next cycle, then take timestamp.
 	na = _alsadev->pcm_wait ();  
-        tw = jacktime (jack_get_time ());
+        tw = tjack (jack_get_time ());
 	// Check for errors - requires restart.
 	if (_alsadev->state () && (na == 0))
 	{
@@ -204,9 +203,9 @@ void Alsathread::thr_main (void)
 		    // If we have more than one period, use
                     // the time error only for the last one.
 	            if (na >= _fsize) er = 0;
-                    else er = modtime (tw - _t1);
+                    else er = tjack_diff (tw, _t1);
 	            _t0 = _t1;
-	            _t1 = modtime (_t1 + _w1 * er + _dt);
+	            _t1 = tjack_diff (_t1 + _dt + _w1 * er, 0.0);
 	            _dt += _w2 * er;
 		}
 	    }
