@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2012-2016 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2012-2018 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -46,20 +46,6 @@ private:
     void send (int k, double t);
     int capture (void);
     int playback (void);
-
-    double modtime (double d)
-    {
-	if (d < -_jtmod / 2) d += _jtmod;
-	if (d >  _jtmod / 2) d -= _jtmod;
-	return d;
-    }
-
-    double jacktime (jack_time_t t)
-    {
-	int32_t u = (int32_t)(t & 0x0FFFFFFFLL); 
-	if (u & 0x08000000) u -= 0x10000000;
-	return 1e-6 * u;
-    }
     
     Alsa_pcmi    *_alsadev;
     int           _mode;
@@ -69,7 +55,7 @@ private:
     Lfq_int32    *_commq;
     Lfq_adata    *_alsaq;
     bool          _first;
-    double        _jtmod;
+//    double        _jtmod;
     double        _t0;
     double        _t1;
     double        _dt;
