@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2012-2016 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2012-2018 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <math.h>
 #include "jackclient.h"
 #include "alsathread.h"
+#include "timers.h"
 
 
 Jackclient::Jackclient (const char *jname, const char *jserv, int mode, int nchan, bool sync) :
@@ -34,8 +35,6 @@ Jackclient::Jackclient (const char *jname, const char *jserv, int mode, int ncha
 {
     init (jname, jserv);
     if (!sync) _resamp = new VResampler ();
-    // Time wraps around after 2^28 usecs.
-    _jtmod = ldexp (1e-6, 28);
 }
 
 
@@ -218,8 +217,8 @@ void Jackclient::setloop (double bw)
     // Set the loop bandwidth to bw Hz.
     w = 6.28 * bw * _bsize / _fsamp;
     _w0 = 1.0 - exp (-20.0 * w);
-    _w1 = w * 1.5 / _bsize;
-    _w2 = w / 1.5;
+    _w1 = w * 2 / _bsize;
+    _w2 = w / 2;
     if (_mode == PLAY) _w1 /= _ratio;
     else               _w1 *= _ratio;
 }
@@ -431,7 +430,7 @@ int Jackclient::jack_process (int nframes)
 
     // Get the start time of the current cycle.
     jack_get_cycle_times (_client, &ft, &t0, &t1, &us);
-    tj = jacktime (t0);
+    tj = tjack (t0);
 
     // Check for any skipped cycles.
     if (_state >= SYNC1)
@@ -487,8 +486,8 @@ int Jackclient::jack_process (int nframes)
     if (_state >= SYNC2)
     {
         // Compute the delay error.
-        d1 = modtime (tj - _t_a0);
-        d2 = modtime (_t_a1 - _t_a0);
+        d1 = tjack_diff (tj, _t_a0);
+        d2 = tjack_diff (_t_a1, _t_a0);
 	rd = _resamp ? _resamp->inpdist () : 0.0;
 
 	if (_mode == PLAY)
