@@ -1,6 +1,6 @@
 // ----------------------------------------------------------------------------
 //
-//  Copyright (C) 2012-2016 Fons Adriaensen <fons@linuxaudio.org>
+//  Copyright (C) 2012-2018 Fons Adriaensen <fons@linuxaudio.org>
 //    
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -55,19 +55,6 @@ private:
 
     void init (const char *jname, const char *jserv);
     void fini (void);
-
-    double modtime (double d)
-    {
-	if (d < -150.0) d += _jtmod;
-	if (d >  150.0) d -= _jtmod;
-	return d;
-    }
-
-    double jacktime (jack_time_t t)
-    {
-        return 1e-6 * (t & 0x0FFFFFFFLL);
-    }
-    
     void initwait (int nwait);
     void initsync (void);
     void setloop (double bw);
@@ -100,7 +87,6 @@ private:
     Lfq_adata      *_alsaq;
     Lfq_jdata      *_infoq;
     double          _ratio;
-    double          _jtmod;
     int             _ppsec;
     int             _bstat;
 
